EventDecoder class

Decoder for AG-UI events.

Supports decoding events from SSE (Server-Sent Events) format and binary format (protobuf or SSE as bytes).

Constructors

EventDecoder()
Creates a decoder instance.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

decode(String data) BaseEvent
Decodes an event from a string (assumed to be JSON).
decodeBinary(Uint8List data) BaseEvent
Decodes an event from binary data.
decodeJson(Map<String, dynamic> json) BaseEvent
Decodes an event from a JSON map.
decodeSSE(String sseMessage) BaseEvent
Decodes a complete SSE message string.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validate(BaseEvent event) bool
Validates that an event has all required fields.

Operators

operator ==(Object other) bool
The equality operator.
inherited