BinaryInputContent class
- Inheritance
-
- Object
- AGUIModel
- InputContent
- BinaryInputContent
Constructors
- BinaryInputContent({required String mimeType, String? id, String? url, String? data, String? filename})
-
const
-
BinaryInputContent.fromJson(Map<
String, dynamic> json) -
factory
Properties
- data → String?
-
An inline data payload (e.g. base64-encoded).
final
- filename → String?
-
An optional display filename.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
An opaque identifier for previously-uploaded content.
final
- mimeType → String
-
The MIME type of the binary payload. Required and non-empty.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
The type discriminator field value.
no setteroverride
- url → String?
-
A URL referencing the content.
final
Methods
-
copyWith(
{String? mimeType, Object? id = _absent, Object? url = _absent, Object? data = _absent, Object? filename = _absent}) → BinaryInputContent -
Creates a copy of this model with optional field updates.
Subclasses should override this with their specific type.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts this model to a JSON map.
override
-
toJsonString(
) → String -
Converts this model to a JSON string.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited